package com.winhc.repal.common;

import com.module.login.usersession.UserBean;
import com.winhc.common.enums.CodeMsg;
import com.winhc.common.exception.CommonException;
import com.winhc.common.util.GSON;
import com.winhc.repal.enums.AppPackageEnum;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.util.Objects;

/**
 * 所有Action的基础类.
 *
 * @author
 */
public abstract class BaseController {

    private static final Log log = LogFactory.getLog(BaseController.class);


    protected HttpServletResponse response;

    public HttpSession getSession() {
        return ((ServletRequestAttributes) Objects.requireNonNull(RequestContextHolder.getRequestAttributes()))
                .getRequest().getSession();
    }

    public HttpServletRequest getRequest() {
        return ((ServletRequestAttributes) Objects.requireNonNull(RequestContextHolder.getRequestAttributes())).getRequest();
    }

    public String getAppid() {
        HttpServletRequest request = getRequest();
        String appId = request.getHeader("appid");
        return appId;
    }

    public String getSessionId() {
        HttpServletRequest request = getRequest();
        String sessionId = request.getHeader("sessionId");
        return sessionId;
    }

    public void getApiInfo() {
        HttpServletRequest request = getRequest();
        String apiVersion = request.getHeader("apiVersion");
        String sessionId = request.getHeader("sessionId");
        String appId = request.getHeader("appid");
        String osType = request.getHeader("osType");
        String deviceId = request.getHeader("deviceId");
        String brand = request.getHeader("brand");
        String osVersion = request.getHeader("osVersion");
        String appVersion = request.getHeader("appVersion");
        String userInfo = request.getHeader("userInfo");
        log.info(" *****************************************************************************************************"
                + "*******************************************************************************************************************");
        log.info(" userInfo :" + userInfo +",apiVersion :" + apiVersion + " ,sessionId: " + sessionId + " , appId: " + appId
                + " ,osType: " + osType + " ,deviceId : " + deviceId + " , brand : " + brand
                + " ,osVersion : " + osVersion + " , appVersion :" + appVersion);
        log.info(" *****************************************************************************************************"
                + "*******************************************************************************************************************");
    }

    /**
     * 获取app版本
     * @return java.lang.String
     * @author xda
     * @date 2021/5/6 14:20
     */
    public String getAppVersion() {
        HttpServletRequest request = getRequest();
        return request.getHeader("appVersion");
    }

    public UserBean getUser() {
        HttpServletRequest request = getRequest();
        String userInfo = request.getHeader("userInfo");
        if (StringUtils.isEmpty(userInfo)) {
            throw new CommonException(CodeMsg.UNAUTHORIZED);
        }
        UserBean user = GSON.fromJson(userInfo, UserBean.class);
        if (Objects.isNull(user)) {
            throw new CommonException(CodeMsg.UNAUTHORIZED);
        }
        log.info(String.format("userInfo:[%s]", GSON.toJSON(user)));
        return user;
    }

    /**
     * 获取包名
     * @return java.lang.String
     * @author xda
     * @date 2021/10/21 09:26
     */
    public String getAppPackageName() {
        return AppPackageEnum.getAppPackageEnum(getRequest().getHeader("appPackage")).getPackageName();
    }

}
