package com.winhc.repal.controller;

import com.winhc.common.base.BeanResponse;
import com.winhc.common.enums.CodeMsg;
import com.winhc.common.model.base.VOPage;
import com.winhc.repal.annotation.RolePermission;
import com.winhc.repal.enums.PermissionEnum;
import com.winhc.repal.model.dto.*;
import com.winhc.repal.model.vo.RepalManageBillDetailVO;
import com.winhc.repal.model.vo.RepalManageBillInfoVO;
import com.winhc.repal.model.vo.RepalManageBillPageVO;
import com.winhc.repal.model.vo.RepalSmsTemplateVO;
import com.winhc.repal.service.RepalBillService;
import com.winhc.repal.service.RepalDynamicService;
import com.winhc.repal.service.RepalVipService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import java.util.List;

/**
 * @author Aaron
 * @date 2022/5/6 11:16
 * @description
 */
@Slf4j
@Api(tags = "催款管理")
@RestController
@RequestMapping("repalManage")
public class RepalManageController {
    @Autowired
    private RepalBillService repalBillService;
    @Autowired
    private RepalDynamicService repalDynamicService;
    @Autowired
    private RepalVipService repalVipService;

    @ApiOperation("汇总")
    @GetMapping("/summary")
    public BeanResponse<RepalManageBillInfoVO> queryManageInfo(){
        return BeanResponse.success(CodeMsg.SUCCESS,repalBillService.queryManageInfo());
    }

    @ApiOperation("分页查询催款列表")
    @GetMapping("/page")
    public BeanResponse<VOPage<RepalManageBillPageVO>> queryManageBillPage(@RequestParam(value = "pageNum",defaultValue = "1")Integer pageNum,
                                                                           @RequestParam(value = "pageSize",defaultValue = "10")Integer pageSize){
        return BeanResponse.success(CodeMsg.SUCCESS,repalBillService.queryManageBillPage(pageNum, pageSize));
    }

    @ApiOperation("查询催款账款详情")
    @GetMapping("/{repalBillId}")
    public BeanResponse<RepalManageBillDetailVO> querManageBillDetail(@PathVariable("repalBillId")Long repalBillId){
        return BeanResponse.success(CodeMsg.SUCCESS,repalBillService.querManageBillDetail(repalBillId));
    }

    @ApiOperation("添加催款动态")
    @PostMapping("/dynamic")
    @RolePermission(permission = PermissionEnum.URGE_BILL)
    public BeanResponse<Boolean> addDynamic(@RequestBody DynamicContentDTO dto){
        return BeanResponse.success(CodeMsg.SUCCESS,repalDynamicService.addDynamic(dto));
    }

    @ApiOperation("获取催款短信模板")
    @GetMapping("/sms/template")
    public BeanResponse<List<RepalSmsTemplateVO>> getSmsTemplate(@RequestParam("repalBillId")Long repalBillId){
        return BeanResponse.success(CodeMsg.SUCCESS,repalDynamicService.getSmsTemplate(repalBillId));
    }

    @ApiOperation("短信催款")
    @PostMapping("/sms/urge")
    @RolePermission(permission = PermissionEnum.URGE_BILL)
    public BeanResponse<Boolean> urgeBySms(@RequestBody RepalSmsDTO dto){
        return BeanResponse.success(CodeMsg.SUCCESS,repalDynamicService.urgeBySms(dto));
    }

    @ApiOperation("律师函催款")
    @PostMapping("/letter/urge")
    @RolePermission(permission = PermissionEnum.URGE_BILL)
    public BeanResponse<Boolean> urgeByLawyerLetter(@RequestBody RepalLetterDTO dto){
        return BeanResponse.success(CodeMsg.SUCCESS,repalDynamicService.urgeByLawyerLetter(dto));
    }

    @ApiOperation("咨询催款")
    @PostMapping("/consult/urge")
    @RolePermission(permission = PermissionEnum.URGE_BILL)
    public BeanResponse<Boolean> urgeByConsult(@RequestBody RepalConsultDTO dto){
        return BeanResponse.success(CodeMsg.SUCCESS,repalDynamicService.urgeByConsult(dto));
    }

    @ApiOperation("诉讼催款")
    @PostMapping("/law/urge")
    @RolePermission(permission = PermissionEnum.URGE_BILL)
    public BeanResponse<Boolean> urgeByLawsuit(@RequestBody RepalLawDTO dto){
        return BeanResponse.success(CodeMsg.SUCCESS,repalDynamicService.urgeByLawsuit(dto));
    }

    @ApiIgnore("取消订单后回复次数")
    @PostMapping("/reply")
    public BeanResponse<Boolean> reply(@RequestBody ReplyDTO dto){
        return BeanResponse.success(CodeMsg.SUCCESS,repalVipService.reply(dto));
    }
}
