package com.winhc.repal.controller;

import com.winhc.common.base.BeanResponse;
import com.winhc.common.enums.CodeMsg;
import com.winhc.repal.annotation.RolePermission;
import com.winhc.repal.enums.PermissionEnum;
import com.winhc.repal.model.dto.AddGroupMemberDTO;
import com.winhc.repal.model.dto.UpdateMemberRoleDTO;
import com.winhc.repal.model.vo.GroupRoleMemberVO;
import com.winhc.repal.model.vo.MemberInfoVO;
import com.winhc.repal.service.RepalGroupMemberService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Description: 组织成员
 * @Author: xda
 * @Date: 2022/5/10 16:11
 */
@Api(tags = "组织成员")
@RestController
@RequestMapping(value = "/member")
public class RepalMemberController {

    @Autowired
    private RepalGroupMemberService repalGroupMemberService;

    @ApiOperation("成员管理列表")
    @RequestMapping(value = "/roleMember", method = RequestMethod.GET)
    public BeanResponse<List<GroupRoleMemberVO>> getGroupRoleMemberList() {
        return BeanResponse.success(CodeMsg.SUCCESS, repalGroupMemberService.getGroupRoleMemberList());
    }

    @ApiOperation("修改当前成员的角色")
    @RequestMapping(value = "/updateMemberRole", method = RequestMethod.POST)
    @RolePermission(permission = PermissionEnum.MEMBER_MANAGER)
    public BeanResponse<Boolean> updateMemberRole(@RequestBody UpdateMemberRoleDTO dto) {
        return BeanResponse.success(CodeMsg.SUCCESS, repalGroupMemberService.updateMemberRole(dto));
    }

    @ApiOperation("添加成员")
    @RequestMapping(value = "/add", method = RequestMethod.POST)
    @RolePermission(permission = PermissionEnum.MEMBER_MANAGER)
    public BeanResponse<Boolean> addGroupMember(@RequestBody AddGroupMemberDTO dto) {
        return BeanResponse.success(CodeMsg.SUCCESS, repalGroupMemberService.addGroupMember(dto));
    }

    @ApiOperation("删除成员")
    @RequestMapping(value = "/del/{userId}", method = RequestMethod.POST)
    @RolePermission(permission = PermissionEnum.MEMBER_MANAGER)
    public BeanResponse<Boolean> delGroupMember(@PathVariable("userId") Long userId) {
        return BeanResponse.success(CodeMsg.SUCCESS, repalGroupMemberService.delGroupMember(userId));
    }

    @ApiOperation("获取成员角色权限")
    @RequestMapping(value = "/permissionList", method = RequestMethod.GET)
    public BeanResponse<List<String>> getMemberPermissionList() {
        return BeanResponse.success(CodeMsg.SUCCESS, repalGroupMemberService.getMemberPermissionList());
    }

    @ApiOperation("获取组织管理员name")
    @RequestMapping(value = "/adminName", method = RequestMethod.GET)
    public BeanResponse<String> getGroupAdminName() {
        return BeanResponse.success(CodeMsg.SUCCESS, repalGroupMemberService.getGroupAdminName());
    }

    @ApiOperation("我的")
    @RequestMapping(value = "/my", method = RequestMethod.GET)
    public BeanResponse<MemberInfoVO> getMemberInfo() {
        return BeanResponse.success(CodeMsg.SUCCESS, repalGroupMemberService.getMemberInfo());
    }


}
