package com.winhc.repal.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.winhc.common.model.base.VOPage;
import com.winhc.repal.entity.RepalBill;
import com.winhc.repal.model.bo.HomeReceivableBO;
import com.winhc.repal.model.dto.*;
import com.winhc.repal.model.vo.*;
import io.swagger.annotations.ApiModelProperty;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;


/**
 * @description RepalBill 接口类
 * @author Generator
 * @date 2022-04-08
 */
public interface RepalBillService extends IService<RepalBill> {

    /**
     * 应收/应付分页列表
     * @param dto dto
     * @return com.winhc.repal.model.vo.RepalBillInfoVO
     * @author xda
     * @date 2022/4/18 12:55
     */
    RepalBillInfoVO getRepalBillPage(GetRepalBillPageDTO dto);

    /**
     * 搜索账本
     * @param dto dto
     * @return com.winhc.common.model.base.VOPage<com.winhc.repal.model.vo.RepalBillPageVO>
     * @author xda
     * @date 2022/5/11 14:03
     */
    VOPage<RepalBillPageVO> searchBill(SearchBillDTO dto);


    /**
     * 获取账款详情
     * @param repalBillId repalBillId
     * @return com.winhc.repal.model.vo.RepalBillDetailVO
     * @author xda
     * @date 2022/4/13 20:26
     */
    RepalBillDetailVO getRepalBillDetail(Long repalBillId);

    /**
     * 删除账款
     * @param dto dto
     * @return java.lang.Boolean
     * @author xda
     * @date 2022/4/15 10:15
     */
    Boolean deleteRepalBillById(DeleteRepalBillDTO dto);

    /**
     * 结清账款
     * @param dto dto
     * @return java.lang.Boolean
     * @author xda
     * @date 2022/4/15 11:06
     */
    Boolean settleRepalBillById(SettleRepalBillDTO dto);

    /**
     * 添加账款
     * @param dto dto
     * @return java.lang.Boolean
     * @author xda
     * @date 2022/4/15 12:24
     */
    Boolean addRepalBill(AddRepalBillDTO dto);
    
    /**
     * 终止账款
     * @param dto dto
     * @return java.lang.Boolean
     * @author xda
     * @date 2022/4/18 12:38
     */
    Boolean breakRepalBill(BreakRepalBillDTO dto);

    /**
     * 终止账款
     * @param dto dto
     * @return java.lang.Boolean
     * @author xda
     * @date 2022/4/18 12:38
     */
    Boolean unBreakRepalBill(BreakRepalBillDTO dto);

    /**
     * 修改账款信息
     * @param dto dto
     * @return java.lang.Boolean
     * @author xda
     * @date 2022/4/15 16:48
     */
    Boolean updateRepalBill(UpdateRepalBillDTO dto);

    /**
     * 删除账本对应的账款以及责任人
     * @param repalBookId repalBookId
     * @return java.lang.Boolean
     * @author xda
     * @date 2022/4/18 12:12
     */
    Boolean deleteRepalBillByBookId(Long repalBookId);

    /**
     * 检查是否一个账本下除了自己外所有账款都刷新完成
     *
     * @param repalBookId
     * @return
     */
    boolean checkAllBillRefreshStatus(Long repalBookId, Long repalBillId);

    /**
     * 分页查询客户下所有的账款(不校验权限)
     * @param pageNum
     * @param pageSize
     * @param custId
     * @return
     */
    VOPage<RepalBillPageVO> getCustRepalBillPage(Integer pageNum, Integer pageSize, Long custId);

    /**
     * 催款管理数据汇总
     * @return
     */
    RepalManageBillInfoVO queryManageInfo();

    /**
     * 分页查询催款管理列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    VOPage<RepalManageBillPageVO>  queryManageBillPage(Integer pageNum, Integer pageSize);

    /**
     * 查询催款管理的详情
     * @param repalBillId
     * @return
     */
    RepalManageBillDetailVO querManageBillDetail(Long repalBillId);

    /**
     * 获取账本下所有账款id
     * @param repalBookId repalBookId
     * @param userId userId
     * @return java.util.List<java.lang.Long>
     * @author xda
     * @date 2022/5/7 17:05
     */
    List<Long> getBillIdListByBookId(Long repalBookId, Long userId);

    /**
     * 获取账本下账款的评级
     * @param repalBookId repalBookId
     * @param userId userId
     * @param start start
     * @param end end
     * @return java.util.List<java.lang.String>
     * @author xda
     * @date 2022/5/7 18:28
     */
    List<String> getBillGradeByBookId(Long repalBookId, Long userId, LocalDateTime start, LocalDateTime end);

    /**
     * 获取
     * @param repalBookId repalBookId
     * @param repalBillType repalBillType
     * @return com.winhc.repal.model.bo.HomeReceivableBO
     * @author xda
     * @date 2022/5/9 12:21
     */
    HomeReceivableBO getBillTotal(Integer repalBillStatus, Long userId, Long repalBookId, Integer repalBillType, LocalDate start, LocalDate end);



    /**
     * 转移账款
     * @param dto dto 
     * @return java.lang.Boolean
     * @author xda
     * @date 2022/5/16 15:26 
     */
    Boolean transferBill(TransferBillDTO dto);

    /**
     * 回款列表
     * @param dto dto 
     * @return com.winhc.common.model.base.VOPage<com.winhc.repal.model.vo.ReturnedBillVO>
     * @author xda
     * @date 2022/5/19 10:11 
     */
    VOPage<ReturnedBillVO> getReturnedBillPage(ReturnedBillDTO dto);


    /**
     * 回款详情
     * @param repalChangeRecordId repalChangeRecordId 
     * @return com.winhc.repal.model.vo.ReturnedBillDetailVO
     * @author xda
     * @date 2022/5/19 12:51 
     */
    ReturnedBillDetailVO getReturnedBillDetail(Long repalChangeRecordId);

    /**
     * 获取
     * @param repalBillId repalBillId
     * @return com.winhc.repal.model.vo.DiagnosisSectionVO
     * @author xda
     * @date 2022/5/25 10:47 
     */
    DiagnosisSectionVO getDiagnosisDynamic(Long repalBillId);

}
