package com.winhc.repal.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.winhc.repal.entity.RepalGroupMember;
import com.winhc.repal.model.dto.AddGroupMemberDTO;
import com.winhc.repal.model.dto.UpdateMemberRoleDTO;
import com.winhc.repal.model.vo.GroupRoleMemberVO;
import com.winhc.repal.model.vo.MemberInfoVO;

import java.util.List;


/**
 * @description RepalGroupMember 接口类
 * @author Generator
 * @date 2022-04-08
 */
public interface RepalGroupMemberService extends IService<RepalGroupMember> {


    /**
     * 根据userId获取member
     * @param userId userId
     * @return com.winhc.repal.entity.RepalGroupMember
     * @author xda
     * @date 2022/5/19 12:59
     */
    RepalGroupMember getMemberByUserId(Long userId);

    /**
     * 获取用户组织id
     * @param userId userId
     * @return java.lang.Long
     * @author xda
     * @date 2022/5/6 11:00
     */
    Long getUserGroupId(Long userId);

    /**
     * 添加组织成员
     * @param userId userId
     * @param userName userName
     * @param groupId groupId
     * @param roleId roleId
     * @param roleType roleType
     * @return java.lang.Boolean
     * @author xda
     * @date 2022/5/6 14:25
     */
    Boolean addGroupMember(Long userId, String userName, Long groupId, Long roleId, Integer roleType);


    /**
     * 修改可见性
     * @param type type
     * @return java.lang.Boolean
     * @author xda
     * @date 2022/5/9 11:13
     */
    Boolean updateVisible(Integer type);

    /**
     * 获取可见性
     * @param type type
     * @return java.lang.Boolean
     * @author xda
     * @date 2022/5/9 11:26
     */
    Boolean getMemberVisible(Integer type);


    /**
     * 获取组织角色成员列表
     * @return java.util.List<com.winhc.repal.model.vo.GroupRoleMemberVO>
     * @author xda
     * @date 2022/5/10 14:47
     */
    List<GroupRoleMemberVO> getGroupRoleMemberList();

    /**
     * 修改成员角色
     * @param dto dto
     * @return java.lang.Boolean
     * @author xda
     * @date 2022/5/11 13:21
     */
    Boolean updateMemberRole(UpdateMemberRoleDTO dto);


    /**
     * 添加组织成员
     * @param dto dto
     * @return java.lang.Boolean
     * @author xda
     * @date 2022/5/11 16:24
     */
    Boolean addGroupMember(AddGroupMemberDTO dto);


    /**
     * 删除组织成员
     * @param userId userId
     * @return java.lang.Boolean
     * @author xda
     * @date 2022/5/16 14:48
     */
    Boolean delGroupMember(Long userId);

    /**
     * 获取成员角色列表
     * @return java.util.List<java.lang.String>
     * @author xda
     * @date 2022/5/17 10:35
     */
    List<String> getMemberPermissionList();

    /**
     * 获取组织管理员name
     * @return java.lang.String
     * @author xda
     * @date 2022/5/23 12:47
     */
    String getGroupAdminName();

    /**
     * 获取成员自己信息
     * @return com.winhc.repal.model.vo.MemberInfoVO
     * @author xda
     * @date 2022/5/23 14:14
     */
    MemberInfoVO getMemberInfo();


}
